"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearCookies = exports.getSessionId = exports.ensureCookies = void 0;
const cookies_1 = __importDefault(require("cookies"));
const crypto_random_string_1 = __importDefault(require("crypto-random-string"));
const ensureCookies = (request, res, { sessionName, sessionKeys, sameSite }) => {
    if (!sessionKeys || sessionKeys.length === 0) {
        throw new Error('sessionKeys are required');
    }
    const cookies = new cookies_1.default(request, res, { keys: sessionKeys });
    let sessionId = cookies.get(sessionName, { signed: true });
    if (!sessionId) {
        sessionId = (0, crypto_random_string_1.default)({ length: 128 });
        cookies.set(sessionName, sessionId, {
            sameSite,
            httpOnly: true,
            path: '/',
            signed: true
        });
    }
    return sessionId;
};
exports.ensureCookies = ensureCookies;
const getSessionId = (request, res, sessionName, sessionKeys) => {
    const cookies = new cookies_1.default(request, res, { keys: sessionKeys });
    return cookies.get(sessionName, {
        signed: true
    });
};
exports.getSessionId = getSessionId;
const clearCookies = (request, res, { sessionName, sameSite }) => {
    const cookies = new cookies_1.default(request, res);
    cookies.set(sessionName, '', {
        sameSite,
        httpOnly: true,
        path: '/'
    });
    cookies.set(`${sessionName}.sig`, '', {
        sameSite,
        httpOnly: true,
        path: '/'
    });
};
exports.clearCookies = clearCookies;
//# sourceMappingURL=cookies.js.map