"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.callbackMiddleware = void 0;
const qs_1 = __importDefault(require("qs"));
const status_1 = require("../status");
const util_1 = require("./util");
const getRedirectPage = (processPathName, redirectQsParameters) => {
    return `
    <html>
        <head>
        </head>
        <body>
            verifying...
            <script>
                window.addEventListener("load", () => {
                    window.location.href = '${processPathName}?${redirectQsParameters}'
                })
            </script>
        </body>
    </html>
`;
};
const callbackMiddleware = (client, pathname, processPathName, options) => {
    return async (ctx) => {
        const { errorPagePath } = options.clientServerOptions;
        try {
            if ((0, util_1.pathsMatch)(ctx.url, pathname)) {
                const callbackParameters = client.callbackParams(ctx.req);
                const redirectQsParameters = qs_1.default.stringify(callbackParameters);
                (0, util_1.showResponse)(200, getRedirectPage(processPathName, redirectQsParameters), ctx.res);
                ctx.done = true;
                return ctx;
            }
        }
        catch (error) {
            ctx.done = true;
            ctx.log.error(error, ctx.url.href);
            (0, util_1.redirectResponse)(`${errorPagePath}?${(0, status_1.qsOfErrorResponse)(status_1.DefaultErrorResponse)}`, ctx.res);
            return ctx;
        }
        return ctx;
    };
};
exports.callbackMiddleware = callbackMiddleware;
//# sourceMappingURL=callback-middleware.js.map