"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cookiesMiddleware = void 0;
const status_1 = require("../status");
const cookies_1 = require("../cookies");
const util_1 = require("./util");
const cookiesMiddleware = (options, sessionStore) => {
    return async (ctx) => {
        const { sessionOptions, clientServerOptions } = options;
        const { callbackPath } = clientServerOptions;
        const { errorPagePath } = options.clientServerOptions;
        try {
            if (!(0, util_1.pathsMatch)(ctx.url, callbackPath)) {
                ctx.sessionId = (0, cookies_1.ensureCookies)(ctx.req, ctx.res, sessionOptions);
                await sessionStore.set(ctx.sessionId, {
                    sessionId: ctx.sessionId
                });
            }
        }
        catch (error) {
            ctx.done = true;
            ctx.log.error(error);
            (0, util_1.redirectResponse)(`${errorPagePath}?${(0, status_1.qsOfErrorResponse)(status_1.DefaultErrorResponse)}`, ctx.res);
            return ctx;
        }
        return ctx;
    };
};
exports.cookiesMiddleware = cookiesMiddleware;
//# sourceMappingURL=cookies-middleware.js.map