"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processCallbackMiddleware = void 0;
const status_1 = require("../status");
const util_1 = require("./util");
const processCallbackMiddleware = (client, pathname, options, sessionStore) => {
    return async (ctx) => {
        var _a, _b, _c;
        const { errorPagePath } = options.clientServerOptions;
        try {
            if ((0, util_1.pathsMatch)(ctx.url, pathname)) {
                if (!ctx.sessionId) {
                    throw new Error('invalid session');
                }
                const session = await sessionStore.get(ctx.sessionId);
                if (!session) {
                    throw new Error('invalid session');
                }
                const { csrfString, codeVerifier } = session;
                if (!csrfString) {
                    throw new Error('invalid session');
                }
                if (codeVerifier) {
                    ctx.log.debug('processing callback with code_verifier');
                }
                // redirectUrl needs to be retrieved before clearing session props
                // to support memory stores
                // Consideration: look at using ramda for default memory store to avoid side effects
                const redirectUrl = (_b = (_a = session.securedPathFromUrl) !== null && _a !== void 0 ? _a : session.fromUrl) !== null && _b !== void 0 ? _b : '/';
                const callbackParameters = client.callbackParams(ctx.req);
                await sessionStore.set(ctx.sessionId, {
                    sessionState: (_c = callbackParameters.session_state) !== null && _c !== void 0 ? _c : null,
                    securedPathFromUrl: null,
                    fromUrl: null,
                    csrfString: null,
                    codeVerifier: null
                });
                const redirectUri = client.metadata.redirect_uris
                    ? client.metadata.redirect_uris[0]
                    : undefined;
                if (options.clientServerOptions.scope &&
                    !options.clientServerOptions.scope.includes('openid')) {
                    ctx.tokenSet = await client.oauthCallback(redirectUri, callbackParameters, {
                        state: csrfString,
                        code_verifier: codeVerifier !== null && codeVerifier !== void 0 ? codeVerifier : undefined
                    });
                }
                else {
                    ctx.tokenSet = await client.callback(redirectUri, callbackParameters, {
                        state: csrfString,
                        code_verifier: codeVerifier !== null && codeVerifier !== void 0 ? codeVerifier : undefined
                    });
                }
                await sessionStore.set(ctx.sessionId, {
                    tokenSet: ctx.tokenSet
                });
                (0, util_1.redirectResponse)(redirectUrl, ctx.res);
                ctx.done = true;
                return ctx;
            }
        }
        catch (error) {
            ctx.done = true;
            ctx.log.error(error, ctx.url.href);
            (0, util_1.redirectResponse)(`${errorPagePath}?${(0, status_1.qsOfErrorResponse)(status_1.DefaultErrorResponse)}`, ctx.res);
            return ctx;
        }
        return ctx;
    };
};
exports.processCallbackMiddleware = processCallbackMiddleware;
//# sourceMappingURL=process-callback-middleware.js.map