"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.proxyMiddleware = void 0;
const status_1 = require("../status");
const util_1 = require("./util");
const proxyMiddleware = (proxyParameters) => {
    const { host, pathname, excludeCookie, excludeOriginHeaders, useIdToken, sessionStore, client } = proxyParameters;
    const { status_code: accessDeniedStatusCode } = status_1.AccessDeniedErrorResponse;
    return async (ctx) => {
        if ((0, util_1.pathsMatch)(ctx.url, pathname)) {
            if (!ctx.sessionId) {
                (0, util_1.sendJsonResponse)(accessDeniedStatusCode, status_1.AccessDeniedErrorResponse, ctx.res);
                ctx.done = true;
                return ctx;
            }
            const session = await sessionStore.get(ctx.sessionId);
            if (!session || !session.tokenSet) {
                (0, util_1.sendJsonResponse)(accessDeniedStatusCode, status_1.AccessDeniedErrorResponse, ctx.res);
                ctx.done = true;
                return ctx;
            }
            if (session.tokenSet.expired()) {
                ctx.log.debug('token is expired');
                if (session.tokenSet.refresh_token) {
                    const tokenSet = await client.refresh(session.tokenSet);
                    ctx.log.debug('refreshed token');
                    await sessionStore.set(ctx.sessionId, { tokenSet });
                    session.tokenSet = tokenSet;
                }
                else {
                    (0, util_1.sendJsonResponse)(accessDeniedStatusCode, status_1.AccessDeniedErrorResponse, ctx.res);
                    ctx.done = true;
                    return ctx;
                }
            }
            let token = session.tokenSet.access_token;
            if (useIdToken) {
                token = session.tokenSet.id_token;
            }
            if (!token) {
                (0, util_1.sendJsonResponse)(accessDeniedStatusCode, status_1.AccessDeniedErrorResponse, ctx.res);
                ctx.done = true;
                return ctx;
            }
            await (0, util_1.executeRequest)({
                token,
                excludeCookie,
                excludeOriginHeaders,
                host,
                pathname,
                ctx,
                method: String(ctx.req.method)
            });
            ctx.done = true;
            return ctx;
        }
        return ctx;
    };
};
exports.proxyMiddleware = proxyMiddleware;
//# sourceMappingURL=proxy-middleware.js.map