"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.signInMiddleware = void 0;
const openid_client_1 = require("openid-client");
const crypto_random_string_1 = __importDefault(require("crypto-random-string"));
const status_1 = require("../status");
const util_1 = require("./util");
const signInMiddleware = (client, pathname, options, sessionStore) => {
    return async (ctx) => {
        const { errorPagePath, enablePKCE } = options.clientServerOptions;
        try {
            if ((0, util_1.pathsMatch)(ctx.url, pathname)) {
                if (!ctx.sessionId) {
                    throw new Error('invalid session');
                }
                const state = (0, crypto_random_string_1.default)({
                    length: 16
                });
                let authUrl;
                let codeVerifier = undefined;
                if (enablePKCE) {
                    ctx.log.debug('building authUrl with code_verifier');
                    codeVerifier = openid_client_1.generators.codeVerifier();
                    ctx.log.debug(`codeVerifier value when building auth url ${codeVerifier}`);
                    const code_challenge = openid_client_1.generators.codeChallenge(codeVerifier);
                    authUrl = client.authorizationUrl({
                        state,
                        scope: options.clientServerOptions.scope,
                        code_challenge,
                        code_challenge_method: 'S256'
                    });
                }
                else {
                    authUrl = client.authorizationUrl({
                        state,
                        scope: options.clientServerOptions.scope
                    });
                }
                let fromUrl = '/';
                if (ctx.req.headers.referer) {
                    fromUrl = (0, util_1.pathFromReferer)(String(ctx.req.headers.referer));
                }
                await sessionStore.set(ctx.sessionId, {
                    codeVerifier,
                    csrfString: state,
                    fromUrl
                });
                ctx.done = true;
                (0, util_1.redirectResponse)(authUrl, ctx.res);
                return ctx;
            }
        }
        catch (error) {
            ctx.done = true;
            ctx.log.error(error);
            (0, util_1.redirectResponse)(`${errorPagePath}?${(0, status_1.qsOfErrorResponse)(status_1.DefaultErrorResponse)}`, ctx.res);
            return ctx;
        }
        return ctx;
    };
};
exports.signInMiddleware = signInMiddleware;
//# sourceMappingURL=signin-middleware.js.map