"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.signOutMiddleware = void 0;
const qs_1 = __importDefault(require("qs"));
const status_1 = require("../status");
const cookies_1 = require("../cookies");
const util_1 = require("./util");
const signOutMiddleware = (pathname, options, sessionStore) => {
    return async (ctx) => {
        var _a;
        const { errorPagePath } = options.clientServerOptions;
        try {
            if ((0, util_1.pathsMatch)(ctx.url, pathname)) {
                ctx.done = true;
                const loggedOutPage = (_a = options.clientServerOptions.signedOutPage) !== null && _a !== void 0 ? _a : '/';
                let sessionState;
                if (ctx.url.search) {
                    const { session_state } = qs_1.default.parse(ctx.url.search);
                    if (session_state) {
                        sessionState = session_state;
                        ctx.log.debug(`session state was parsed from ctx.url.search as ${String(sessionState)}`);
                    }
                }
                if (sessionState) {
                    const session = await sessionStore.getByPair('sessionState', sessionState);
                    ctx.log.debug(`session = ${JSON.stringify(session)}`);
                    if (session) {
                        await sessionStore.destroy(session.sessionId);
                        (0, util_1.redirectResponse)(loggedOutPage, ctx.res);
                        return ctx;
                    }
                    ctx.log.debug(`signout process was unable to find a session via session state ${sessionState}`);
                }
                if (!ctx.sessionId) {
                    ctx.log.debug(`signout process was unable to find a session. redirecting to logged out page ${loggedOutPage}`);
                    (0, util_1.redirectResponse)(loggedOutPage, ctx.res);
                    return ctx;
                }
                ctx.log.debug(`signout destroying session ${ctx.sessionId}. redirecting to logged out page ${loggedOutPage}`);
                await sessionStore.destroy(ctx.sessionId);
                (0, cookies_1.clearCookies)(ctx.req, ctx.res, options.sessionOptions);
                (0, util_1.redirectResponse)(loggedOutPage, ctx.res);
                return ctx;
            }
        }
        catch (error) {
            ctx.log.error(error);
            (0, util_1.redirectResponse)(`${errorPagePath}?${(0, status_1.qsOfErrorResponse)(status_1.DefaultErrorResponse)}`, ctx.res);
            return ctx;
        }
        return ctx;
    };
};
exports.signOutMiddleware = signOutMiddleware;
//# sourceMappingURL=signout-middleware.js.map