/// <reference types="node" />
import type { LoggerOptions } from 'pino';
import type { ClientMetadata } from 'openid-client';
export declare class OptionsError extends Error {
    constructor(message: string);
}
export type ClientServerOptions = {
    discoveryEndpoint: string;
    scope?: string;
    enablePKCE: boolean;
    enableOauth2: boolean;
    signInPath: string;
    callbackPath: string;
    processCallbackPath: string;
    signOutPath: string;
    userInfoPath: string;
    errorPagePath: string;
    signedOutPage?: string;
    securedPaths?: string[];
    authorizationEndpoint: string;
    tokenEndpoint: string;
    userInfoEndpoint?: string;
    emitEvents?: boolean;
};
export type SessionOptions = {
    sessionName: string;
    sessionKeys: string[];
    sameSite: boolean;
};
export type ProxyOptions = {
    proxyPaths: string[];
    proxyHosts: string[];
    excludeCookie: boolean[];
    useIdToken: boolean[];
    excludeOriginHeaders: boolean[];
};
export type Options = {
    clientServerOptions: ClientServerOptions;
    sessionOptions: SessionOptions;
    clientMetadata: ClientMetadata;
    loggerOptions: LoggerOptions;
    loggerDestination?: NodeJS.WritableStream;
    proxyOptions: ProxyOptions;
};
export declare const resolveOptions: () => Options;
