import type { TokenSet, UserinfoResponse } from 'openid-client';
import type { Json } from './json';
export type Profile = Record<string, any>;
export type SessionMemCache = Record<string, unknown | any> & Map<string, Session>;
export type Session = {
    sessionId: string;
    createdAt: number;
    csrfString: string | undefined;
    codeVerifier: string | undefined;
    tokenSet: TokenSet | undefined;
    userInfo: UserinfoResponse | undefined;
    sessionState: string | undefined;
    fromUrl: string | undefined;
    securedPathFromUrl: string | undefined;
} & Json;
export type SessionStore = {
    clear(): Promise<void>;
    destroy(sessionId: string): Promise<void>;
    get(sessionId: string): Promise<Session | undefined>;
    getByPair(key: string, value: string): Promise<Session | undefined>;
    set(sessionId: string, sessionPatch: Json): Promise<void>;
};
export declare class MemorySessionStore implements SessionStore {
    cache: SessionMemCache;
    constructor();
    clear(): Promise<void>;
    destroy(sessionId: string): Promise<void>;
    getByPair(key: string, value: string): Promise<Session | undefined>;
    get(sessionId: string): Promise<Session | undefined>;
    set(sessionId: string, sessionPatch: Json): Promise<void>;
}
