"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MemorySessionStore = void 0;
class MemorySessionStore {
    constructor() {
        this.cache = new Map();
    }
    async clear() {
        this.cache.clear();
    }
    async destroy(sessionId) {
        this.cache.delete(sessionId);
    }
    async getByPair(key, value) {
        for (const entry of this.cache.entries()) {
            const session = entry[1];
            if (session[key] === value) {
                return session;
            }
        }
    }
    async get(sessionId) {
        return this.cache.get(sessionId);
    }
    async set(sessionId, sessionPatch) {
        let session = await this.get(sessionId);
        if (!session) {
            session = {
                sessionId,
                createdAt: Date.now(),
                csrfString: null,
                codeVerifier: null,
                tokenSet: null,
                userInfo: null,
                sessionState: null,
                fromUrl: null,
                securedPathFromUrl: null
            };
        }
        session = Object.assign(session, sessionPatch);
        this.cache.set(sessionId, session);
    }
}
exports.MemorySessionStore = MemorySessionStore;
//# sourceMappingURL=session.js.map